## Synopsis

Layers is a WordPress Theme framework focused on extending the WordPress core functionality to include layout building through the WordPress Visual Customizer. A lightweight set of base options, widgets and theme templates provide a user-friendly, extensible tool for creating beautiful, WordPress-faithful websites.

As a framework, Layers is not intended for direct modification. Instead, it allows you to backup pages and widget data to create presets or “Style Kits” which you can share, sell, or use to seamlessly transfer setups and layouts from one install to another. Layers may also be extended through Child Themes and Plugins via a growing set of hooks, snippets and tips found in our Developer Reference library.

## Download & Install

Layers is available from our GitHub link here, or from layerswp.com and requires a self-hosted WordPress install.

View WordPress installation and server requirements on the [WordPress Codex](https://wordpress.org/download/)

To install Layers, upload the layers zip file to your self-hosted WordPress install under APPEARANCE →THEMES → ADD NEW.

Upon Activation, you will be greeted with a quick overview and be prompted to choose a preset.

Custom page layouts are achieved using the WordPress Customizer in combination with widgets.  You can access Layers customization from APPEARANCE → CUSTOMIZE or through any Layers Page.  These pages are listed under LAYERS → LAYERS PAGES for your convenience.

Customization of these pages and the overall theme is completed in the WordPress Customizer to take advantage of the live view.

For videos, troubleshooting and detailed usage documentation, view the Getting Started  Guide

###Links

* [LayersWP](http://www.layerswp.com/download/layers/)
* Clone here or [Download Master](https://github.com/Obox/layerswp/archive/master.zip)
* *Send us a pull request!*

## Page Builder

The core concept of Layers is to enable the user to build layouts using functionality that is native to WordPress. This page template simply provides a single widget area that is designed to work with the Layers Page Builder Widgets specifically, but can accomodate most any widget with a little custom styling.

[Learn how the page builder works](http://docs.layerswp.com/doc/build-your-home-page/)

## Page Templates

Layers bundles 6 basic page templates to allow sidebar specificity per page, and a standard blog feed which uses the Layers Site Settings sidebar selection.

[View Page Template detail](http://docs.layerswp.com/doc/page-templates/)

## Framework

Layers is built upon a lightweight HTML5 & CSS framework designed for speed, comprehension and efficient building of Child Themes and Extensions. It uses a 12ths grid and includes styling for buttons, forms, content typography, navigation and images.

* Framework Guide with code examples: [Start Here](http://docs.layerswp.com/layers-framework-grids/)
* [Framework Visual Reference](http://docs.layerswp.com/framework/)

## Technical Information

### Browser & Device Support

Layers is built to work best in the latest desktop and mobile browsers, meaning older browsers might display differently styled, and only partially functional, renderings of certain components.

### Supported Browsers

We support the latest versions of the following browsers and platforms. More specific support information is provided [here](http://docs.layerswp.com/about-layers/#technical-information).

### Responsiveness

Layers is fully responsive, supporting most modern smartphone, tablet and laptop screen resolutions. It includes thresholds for 320, 600, and 768 by default.

### Code Libraries & APIs

Layers uses jQuery, JSON, and other libraries pre-bundled with the WordPress platform which you can reference on the [WordPress Codex](http://codex.wordpress.org/Function_Reference/wp_enqueue_script#Default_Scripts_Included_and_Registered_by_WordPress).

Additionally, Layers includes Isotope, which you can learn more about extending and cusomizing on our [Codex](http://docs.layerswp.com).

## Translations

Layers is coded in international English as the primary language and uses WordPress standard [gettext](http://codex.wordpress.org/I18n_for_WordPress_Developers) to enable quick and easy translation of text elements via plugins or .po file editors. Several professional translations are available from the Layers Extension library for use on your site or in a child theme project, or you may translate Layers yourself using any of the following solutions:

* Codestyling Localization (free plugin)
* WPML (premium plugin) + String Translation (WPML Extension for Theme localization)
* POEdit (desktop tool for creating .po files manually)

## License

Layers is released under the [GPL 2.0 License.](https://wordpress.org/about/gpl/)

The specific implementation and design are copyright 2014 by Obox Themes.

Boiled down to smaller chunks, the license sets forth the following conditions:

It allows you to:

* Freely download and use Layers, in whole or in part, for personal, company-internal or commercial purposes
* Build Child Themes or Extensions for use with or based on the Layers framework for personal use or a client project
* Install Layers on as many websites as you wish

It forbids you to:

* Redistribute Layers in whole or part without proper attribution.

It requires you to:

* Include a copy of the license in any redistribution you may make that includes Layers
* Provide clear attribution to the Layers Team for any distributions, Child Themes or Extensions that include Layers

It does not require you to:

* Include the full source of Layers itself, or of any modifications you may have made to it, in any redistribution you may assemble that includes it (such as a child theme or extension)
* Submit changes that you make to Layers back to the Layers project (though you earn extra awesome points for doing so!)

###Extra info regarding commercial sale of Child Themes or Extensions for Layers:

You may sell any product created for Layers on your own site or a theme marketplace. You may link to our documentation to help support your customers, but take on all developmental responsibility and support for your product where it is specific to your code. For your own sanity, we recommend you direct your users to download Layers from our official links to ensure they receive the most recent versions, and read through our developer documentation and best practices.

You may not create a hosted service that charges users for Layers, or include Layers in a hosted-for-a-fee without also providing a clear link to where the source may be downloaded for free. (ie providing the source code to your users)

## Theming & Extending

Our Codex contains a growing reference for custom hooks found in Layers, along with core functions, definitions and child-theming resources.

* [Child Theme Introduction](http://docs.layerswp.com/child-themes-introduction/)
* [Theme Structure](http://docs.layerswp.com/theme-structure/)
* [Code Reference](http://docs.layerswp.com/reference/)

## Contributing

We welcome any contributions to the core, or theme and extension submissions! Please send us a pull request against the Develop Branch

* For core contribution, [fork the project](https://github.com/Obox/layerswp/fork)
* To report a bug, hit up our[issues list](https://github.com/Obox/layerswp/issues/new?title=Issue%3A%20&body=%23%23%20Description%20of%20issue%0A%0A%0A%23%23%20URL%20of%20page%20exhibiting%20the%20issue%0A%0A%0A%23%23%20Web%20Browsers%20that%20exhibit%20the%20issue%0A%0A%0A%23%23%20Error%20Message%20or%20Steps%20to%20Recreate%0A%0A)
* For development questions or inquiries related to commercial sale of child themes or extensions, email layers@obox.co.za